pycocoa.lazily.LazyAttributeError

Package pycocoa :: Module lazily :: Class LazyAttributeError |
[frames] | no frames]

# Class LazyAttributeError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
               exceptions.AttributeError --+
                                           |
                                          LazyAttributeError

Raised if an attribute can't be `lazily imported`.

Instance Methods
Inherited from `exceptions.AttributeError`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`